// Copyright 2017 The Johns Hopkins University Applied Physics Laboratory.
// Licensed under the MIT License. See LICENSE.txt in the project root for full license information.

#pragma once

#include <string>
#include <memory>

#include <eopcc/cloud.hpp>
#include <eopcc/grid_structs.hpp>

#include <eopcc/io.hpp>
#include <eopcc/ply_io.hpp>

namespace liblas {
	class Reader;
}


namespace eopcc {

  const int kLasIncludesRGB = 2;

  void TransferColors(std::string point_source, std::string color_source, std::string output_name);

  void LoadFromLAS(const std::string& las_file_name, PointCloud& point_cloud);
  void WriteToLAS(const std::string& las_file_name, const PointCloud& point_cloud);

  // Readers and Writers that allow streaming
  class LASReader : public PointCloudReader {
  private:
	  std::unique_ptr<::liblas::Reader> reader_;
    PointCloud seed_cloud_;
    int ptformat_;
    size_t num_points_remaining_;

  public:
    LASReader(const std::string& filename);
    ~LASReader();
    virtual PointCloud GetSeedCloud() { return seed_cloud_; }
    virtual PointCloud ReadSubCloud(int sub_cloud_size);
    virtual size_t NumRemainingPoints() { return num_points_remaining_; }
  };


} // eopcc
